###############################################################################################
###############################################################################################
###
###     Ecrans / Screens
###
###############################################################################################
###############################################################################################

##############################################################################
# Screens pour les crédits
#
#
#------------------------------------------------------------------------------------
# Screen général
screen credit(type,illu,description):
# type = l'écran est différent pour une image ou un fichier audio
# Illu = image qui sera affichée comme illustration (la photo, la couv de l'album, la représentation du bruitage)
# description = éléments pour la desciption (sous forme de tableau): auteur, nom de l'asset, licence, ...
    window:
        style "st_credit" ## TODO ? Coder le fond dans les styles ?
        #xsize 300
        #xpos 730
        #ypos 45

        text _("{color=[couleur_narration]}Crédits{/color}"):
            xpos 884
            ypos 45
            #xsize 300
            #xfill True
            xalign 0.5
            size 35
            #text_align 0.5
            
    # À gauche : on a soit une simple image, soit image + boutons si c'est du son, donc un screen spécial (audio_illu)
    if type == "audio":
        use audio_illu(illu)
    else:
        add illu anchor (0.5,0.5) ypos 306 xpos 340
        
    # les items sont différents si on décrit une image ou du son (chacun a son propre screen)
    # on garde une solution par défaut où on reproduit simplement la chaine de caractère passée en argument
    if type == "audio":
        use audio_description(description)
    elif type == "image":
        use image_description(description)
    else:
        vbox:
            xpos 715
            ypos 100
            xsize 330
            text description style "st_credit"
            
    use menu_rapide()
    
style st_credit:
    color "#ccc" # couleur du texte
    background "fonds credits"
    
    
#-----------------------------------------------------------------------------
# Affichage de la pochette et des boutons pour jouer musiques et sons (pour les crédits)
#
# Définition d'un channel spécifique pour les extraits audio
init python:
    renpy.music.register_channel('extraits', mixer='sample', loop=False)

screen audio_illu(donnees):
    
    ##### Ces instructions permettent de récupérer et restaurer le volume du mixer qui passe le générique
    ##### avec les boutons et quand on change passe au crédit suivant:
    
    #-- On récupère le volume du mixer de la musique de fond en entrant dans le screen
    on "show" action [SetVariable('music', _preferences.get_volume('music'))]
    on "replace" action [SetVariable('music', _preferences.get_volume('music'))]
    #-- On coupe l'extrait et on restaure le volume en allant au screen suivant
    on "replaced" action [Stop("extraits"),SetMixer("music",music)]
    on "hide" action [Stop("extraits"),SetMixer("music",music)]
    
    vbox:
        style_group "audioillu"
        xanchor 0.5
        ypos 100
        xpos 340
        #--- on affiche l'illustration (pochette d'album ou oscillo du son
        add donnees['illu']
        null height 20
        
        ### On affiche deux bouton pour jouer la musique/son ou la couper
        #--- Ce bouton joue la musique de l'asset, en coupant le volume du mixer du générique
        textbutton _("Jouer") action [SetMixer("music",0.0),Play("extraits",donnees['morceau'])]
        null height 20
        #--- Ce bouton coupe la musique de l'asset et rétablit le volume du mixer du générique
        textbutton _("Stop") action [Stop("extraits"),SetMixer("music",music)]

# pour mettre tous les boutons à la même largeur
init -2:
    style audioillu_button is bouton_cadre:
        size_group "audioillu"
    # Homogénéisation des styles => semblables aux boutons de la barre des pages de signets.
    style audioillu_button_text is bouton_cadre_texte
        
        
        
#-----------------------------------------------------------------------------
# Affichage de la description des musiques / sons
#
screen audio_description(infos):
    
    $ licence = affich_licence(infos['licence'],infos['version'])
    
    vbox:
        xpos 715
        ypos 100
        xsize 330
        
        # Affichage du titre de la description en fonction de la langue
        if _preferences.language == None:
            $ lang = "fr"
        else:
            $ lang = _preferences.language
        $ types = {"musique": {"fr":"Musique","en":"Music"},"son":{"fr":"Effet sonore","en":"Sound effect"}}
        
        text "{b}" + types[infos['type']][lang] + "{/b}" style "st_credit"
        null height 20
        $ par = _('par')
        text "[infos[titre]] [par!t] [infos[auteur]]" style "st_credit"
        null height 20
        if infos['type'] == "musique":
            text _("Album : ") + infos ['album'] style "st_credit"
        null height 20
        # On vérifie si le type de licence est défini, sinon on met Creative Commons par defaut (compatibilités avec vieilles versions)
        if "type_lic" not in infos.keys():
            $ type_lic = "Creative Commons"
        else:
            $ type_lic = infos['type_lic']
        if _preferences.language == None:
            $ credit_licence = "sous licence %s" % type_lic
        else:
            $ credit_licence = "under %s license" % type_lic
        text  "[credit_licence]" style "st_credit"
        text licence style "st_credit"
        null height 20
        $ ecouter = _("}Écouter sur")
        text "{a=[infos[lien]][ecouter!t] [infos[site]]{/a}" style "st_credit"

    
#-----------------------------------------------------------------------------
# Affichage de la description des images
# 
screen image_description(infos):
    
    $ licence = affich_licence(infos['licence'],infos['version'])
    
    vbox:
        xpos 715
        ypos 100
        xsize 330
        
        text "{b}" + infos['titre'] + "{/b}" style "st_credit"
        null height 20
        $ par = _('par')
        text "[par!t] [infos[auteur]]" style "st_credit"
        if infos ['pseudo'] is not None:
            text "(" + infos ['pseudo'] + ")" style "st_credit"
        null height 20
        $ original = _("}original sur ")
        # On vérifie si le type de licence est défini, sinon on met Creative Commons par defaut (compatibilités avec vieilles versions)
        if "type_lic" not in infos.keys():
            $ type_lic = "Creative Commons"
        else:
            $ type_lic = infos['type_lic']
        if _preferences.language == None:
            $ souslicence = "{/a}\n\nsous licence %s" % type_lic
        else:
            $ souslicence = "{/a}\n\nunder %s license" % type_lic
        # On vérifie si un nom de site est défini, sinon on laisse Flickr par défaut (compatibilités avec vieilles versions)
        if "site" not in infos.keys():
            $ site = "Flickr"
        else:
            $ site = infos['site']
        text "{a=[infos[lien]][original!t][site][souslicence]"  style "st_credit"
        text licence style "st_credit"

##############################################################################
# Screens pour les pauses
#
screen ecran_pause():
    
    # On empêche d'interagir avec ce qui est affiché en dessous
    modal True
    
    # on met les volumes de la musique et des sons à zéro quand on rentre dans le screen
    on "show" action [SetVariable('music', _preferences.get_volume('music')),SetVariable('son', _preferences.get_volume('sfx')), SetMixer("music",0.0),SetMixer("sfx",0.0)]
    
    # on le remet les volumes à leur niveau initial quand on sort du screen
    on "hide" action [SetMixer("music",music),SetMixer("sfx",son)]
    
    # on recouvre l'écran avec un voile gris
    add Solid("#000c")
    
    # on utilise un tooltip pour afficher la légende du bouton pause qui suit
    default tt = Tooltip("")
    text tt.value align(0.65,0.5)
    
    # on ajoute un signe de pause, qui sert de bouton
    imagebutton:
        auto "gui/pause/icone_pause_%s.png" align (0.5,0.5)
        focus_mask True
        action Hide("ecran_pause")
        hovered tt.Action(_("Reprendre")) 

        
##############################################################################
# Menu des options
#
# Ceci met le "menu des options" comme menu par défaut "clic droit / échap"
init python:
    _game_menu_screen = "menu_options"

screen menu_options:
    # Ecran qui s'affiche quand on clique droit ou qu'on y accède par l'accueil ou le menu rapide
       
    # Pour être sûr que tout autre menu est remplacé
    tag menu

    # Fond du menu jeu
    window:
        style "ecran_options"

    # Boutons de navigation.
    frame:
        style_group "mo"
        xalign 0.5
        yalign 0.5

        has vbox
        
        hbox:
            $ preferences = _("Preferences")
            textbutton u"{font=gui/open-iconic.ttf}{size=40}\uE0DA{/size}{/font}\n[preferences!t]" action ShowMenu("reglages")
            $ retour = _("Return")
            textbutton u"{font=gui/open-iconic.ttf}{size=40}\uE003{/size}{/font}\n[retour!t]" action Return()
        hbox:
            $ load = _("Load Game")
            textbutton u"{font=gui/open-iconic.ttf}{size=40}\uE021{/size}{/font}\n[load!t]" action ShowMenu("use_signet")
            $ main = _("Main Menu")
            textbutton u"{font=gui/open-iconic.ttf}{size=40}\uE078{/size}{/font}\n[main!t]" action MainMenu()
        hbox:
            $ save = _("Save Game")
            textbutton u"{font=gui/open-iconic.ttf}{size=40}\uE021{/size}{/font}\n[save!t]" action [ShowMenu("pose_signet"), SensitiveIf(main_menu is not True)]
            $ quit = _("Quit")
            textbutton u"{font=gui/open-iconic.ttf}{size=40}\uE0AB{/size}{/font}\n[quit!t]" action Quit()

init -2:
    style mo_button is default:
        size_group "mo"
        xpadding 25
        ypadding 25
        xmargin 15
        ymargin 15
        background Frame(recolorer("gui/cadre_bouton.png",couleur_ombre),4,4)
        insensitive_background Frame(recolorer("gui/cadre_bouton.png",couleur_insensitive),4,4)
        hover_background Solid(couleur_ombre)

    style ecran_options:
        background "titre fond ivy"
        
    style mo_frame:
        background Solid(couleur_fond)
        
        
    style mo_button_text:
        color couleur_interieur
        outlines [(1,couleur_exterieur,0,0)]
        insensitive_color couleur_insensitive
        insensitive_outlines []
        xalign 0.5
        text_align 0.5
    
##############################################################################
# Menu principal
#
# Écran utilisé pour le menu principal, quand Ren'Py démarre

screen main_menu:

    # Pour être sûr que tout autre menu est remplacé
    tag menu

    # Le fond du menu principal
    window:
        style "fond_accueil"
        
    # Les boutons du menu principal.
    frame:
        style_group "accueil"
        xalign 0.5
        yalign 0.95
        background None

        has hbox

## Provisoire tant qu'il n'y a pas de traductions => On montre le menu d'aide
#        imagebutton:
#            style "accueil_button"
#            idle Text(u"\uE0B0",style = "accueil_idle")
#            hover Text(_("Help"), style = "accueil_hover")
#            action Help()

## Désactivé tant qu'il n'y a pas de traductions
        imagebutton:
            style "accueil_button"
            idle Text(u"\uE069",style = "accueil_icone")
            if _preferences.language == None:
                hover Text("Read in\nEnglish", style = "accueil_texte")
                action Language("en")
            else:
                hover Text("Lire en\nfrançais", style = "accueil_texte")
                action Language(None)
        
        imagebutton:
            style "accueil_button"
            idle Text(u"\uE021",style = "accueil_icone")
            hover Text(_("Bookmark"), style = "accueil_texte")
            action ShowMenu("use_signet")
        
        imagebutton:
            style "accueil_button"
            xsize 200
            idle Text(u"\uE0A9",style = "accueil_icone", size = 80)
            hover Text(_("Read"), style = "accueil_texte" ,size = 50)
            action Start()
        
        imagebutton:
            style "accueil_button"
            idle Text(u"\uE041",style = "accueil_icone")
            hover Text(_("Options"), style = "accueil_texte")
            action ShowMenu("menu_options")
        
        imagebutton:
            style "accueil_button"
            idle Text(u"\uE0AB",style = "accueil_icone")
            hover Text(_("Quit"), style = "accueil_texte")
            action Quit(confirm=False)
            
    add "titre legende ivy" pos(358,0)
        

init -2:
    # styles pour l'affichage des boutons de l'écran d'accueil
    style fond_accueil:
        background "titre fond ivy"


    # styles pour l'affichage des boutons de l'écran d'accueil
    style accueil_icone is titre:
        font "gui/open-iconic.ttf"
        size 30
        #text_align 0.5
        xalign 0.5
        yalign 0.5
    
    style accueil_texte is titre:
        text_align 0.5
        xalign 0.5
        yalign 0.5

        
    style accueil_button:
        xminimum 185
        ysize 100
        xmargin 25

##############################################################################
# Menu de navigation
#
# menu inclus dans d'autres menus pour permettre la navigation
    
screen navigation:

    # on définit l'endroit où mène le bouton d'aide
    default label_aide = config.help
    # Fond du menu jeu
    window:
        style "ecran_options"
        
    frame:
        style_group "accueil"
        xalign 0.5
        yalign 0.97
        background None

        has hbox

        imagebutton:
            style "accueil_button"
            idle Text(u"\uE0B0",style = "accueil_icone")
            hover Text(_("Help"), style = "accueil_texte")
            action Help(label_aide)
        
        imagebutton:
            style "accueil_button"
            xsize 300
            idle Text(u"\uE003",style = "accueil_icone", size = 80)
            hover Text(_("Return"), style = "accueil_texte" ,size = 50)
            action Return()
       
        imagebutton:
            style "accueil_button"
            idle Text(u"\uE0AB",style = "accueil_icone")
            hover Text(_("Quit"), style = "accueil_texte")
            action Quit()

##############################################################################
# Menu des réglages
#
# Menu de réglage des préférences et paramètres

screen reglages:
    
    # Pour être sûr que tout autre menu est remplacé
    tag menu
    
    # utilisation du menu de navigation (dans lequel le fond est inclus)
    use navigation(label_aide="aide_reglages")
    # le paramètre fait en sorte que le bouton d'aide mène directement à la page de l'aide des préférences.
    
    text _("Preferences"):
        style "titre_ecran"
        
    frame:
        style_group "options"
        
        has hbox
        
        vbox:
            
            $ display = _("Display")
            text u"{font=gui/open-iconic.ttf}\uE0A0{/font} [display!t]" 
            hbox:
                $ window = _("Window")
                textbutton u"{font=gui/open-iconic.ttf}{size=30}\uE026{/size}{/font}\n[window!t]":
                    action Preference("display", "window")
                $ fullscreen = _("Fullscreen")
                textbutton u"{font=gui/open-iconic.ttf}{size=30}\uE09E{/size}{/font}\n[fullscreen!t]":
                    action Preference("display", "fullscreen")
            
            $ volume = _("Volume")
            text u"{font=gui/open-iconic.ttf}\uE0D5{/font} [volume!t]"
            bar:
                value Preference("music volume")

            $ langue = _("Langue/Language")    
            text u"{font=gui/open-iconic.ttf}\uE069{/font} [langue!t]"
            hbox:
                textbutton "{font=gui/fonts/TruenoBlkOl.otf}{size=30}fr{/size}{/font}\nFrançais":
                    action Language(None)
                textbutton "{font=gui/fonts/TruenoBlkOl.otf}{size=30}en{/size}{/font}\nEnglish":
                    action Language("en")
                
            
        vbox:
            $ text_speed = _("Text Speed")
            text u"{font=gui/open-iconic.ttf}\uE096{/font} [text_speed!t]"
            bar:
                value Preference("text speed")
                
            $ auto_forward = _("Auto-Forward")
            text u"{font=gui/open-iconic.ttf}\uE098{/font} [auto_forward!t]" 
            hbox:
                $ yes =  _("Yes")
                textbutton u"{font=gui/open-iconic.ttf}{size=30}\uE038{/size}{/font}\n[yes!t]":
                    action Preference("auto-forward", "enable")
                $ no = _("No")
                textbutton u"{font=gui/open-iconic.ttf}{size=30}\uE039{/size}{/font}\n[no!t]":
                    action Preference("auto-forward", "disable")
            $ auto_forwardt = _("Auto-Forward Time")        
            text u"{font=gui/open-iconic.ttf}\uE0CD{/font} [auto_forwardt!t]"
            bar:
                value Preference("auto-forward time")

                
init -2:
    style options_frame is cadre:
        xmargin 75
        ymargin 75
        ypadding 10
        xpadding 20
        xfill True
        
    style options_hbox:
        spacing 25
        xalign 0.5
        
    style options_vbox:
        spacing 25
        xsize 444
        xfill True
        
    style options_slider is barre:
        xsize 300
        
        
    style options_button:
        size_group "options"
        background None
        
    style options_text is titre:
        size 28
    
    style options_button_text:
        color couleur_ombre
        outlines [(0,couleur_exterieur,1,1)]
        
        hover_color couleur_ombre
        hover_outlines [(0,couleur_interieur,1,1)]
        
        selected_color couleur_interieur
        selected_outlines [(0,couleur_exterieur,1,1)]
        
        insensitive_color couleur_insensitive
        
        size 16
        
        text_align 0.5

    style titre_ecran is titre:
        size 50
        xalign 0.5
        yalign 0.02
        
##############################################################################
# Menu rapide perso
#
# Écran inclus par défaut pour les dialogues, ajoutant un accès rapide à 
# plusieurs fonctions utiles

#-----------------------------------------------------------------------------
# Definitions d'images pour les icones du menu rapide
define music = 0.0  # on initialise les variables qui vont servir à conserver la valeur des mixers
define son = 0.0    # sinon après il y aura des erreurs 

define quick_boutons = [
                {
                "image" : u"\uE092",
                "texte":_("Pause"),
                "action":Show("ecran_pause"),
                "nom":"pause"},
                
                {
                "image" : u"\uE0B0",
                "texte":_("Help"),
                "action":Help("aide_rapide"),
                "nom":"aide"},
                
                {
                "image" : u"\uE093",
                "texte":_("Auto On"),
                "action":Preference("auto-forward", "toggle"),
                "nom":"avance_auto"},
                
                {
                "image" : u"\uE095",
                "texte":_("Back"),
                "action":Rollback(),
                "nom":"rollback"},
                
                {
                "image" : u"\uE041",
                "texte":_("Options"),
                "action":ShowMenu('menu_options'),
                "nom":"prefs"}
                ]

#-----------------------------------------------------------------------------
# Screen en lui-même
screen menu_rapide:

    # Ajoute un menu rapide au sein du jeu
    vbox:
        #style_group "quick"

        xalign 1.0
        yalign 1.0
        xoffset -4

        for i in range(len(quick_boutons)):
                imagebutton: 
                    yminimum 18
                    xalign 1.0
                    
                    idle Text(quick_boutons[i]["image"],style="quick_button_idle")
                    hover Text(quick_boutons[i]["texte"],style="quick_button_hover")
                    insensitive Text(quick_boutons[i]["image"],style="quick_button_insensitive")
                    
                    if quick_boutons[i]["nom"] == "avance_auto":
                        selected_idle Text(u"\uE099",style="quick_button_selected")
                    else:
                        selected_idle Text(quick_boutons[i]["image"],style="quick_button_selected")
                    if quick_boutons[i]["nom"] == "avance_auto":
                        selected_hover Text(u"Auto Off",style="quick_button_hover")
                    action quick_boutons[i]["action"]
                null height 5

init -2 python:
    style.quick_button.set_parent('default')
    style.quick_button.background = None
    
    style.quick_button_text.set_parent('default')
    style.quick_button_text.size = 12

    style.quick_button_image.set_parent('quick_button')
    style.quick_button_image.font="gui/open-iconic.ttf"
    style.quick_button_image.size=14
    
    style.quick_button_idle = Style(style.quick_button_image)
    style.quick_button_idle.color = "#ddd8"
    style.quick_button_idle.outlines = [(1,"#0008",1,1)]
    
    style.quick_button_hover = Style(style.quick_button_text)
    style.quick_button_hover.color = "#ddd8"
    style.quick_button_hover.outlines = [(1,"#0008",1,1)]

    style.quick_button_selected = Style(style.quick_button_image)
    style.quick_button_selected.color = "#3338"
    style.quick_button_selected.outlines = [(1,"#fff8",1,1)]

    style.quick_button_insensitive = Style(style.quick_button_image)
    style.quick_button_insensitive.color = "#7778"

##############################################################################
# Sauvegarder, Charger
#
# Écrans permettant à l'utilisateur de sauvegarder ou charger un jeu

# Puisque la sauvegarde et le chargement sont deux actions proches
# nous utilisons un seul écran pour les deux. On utilise un l'écran
# grille_signets depuis les écrans de sauvegarde et et de chargement.

screen grille_signets:

    vbox:
        style_group "signets"
        # premier cadre pour le choix de la page
        frame:
            
            top_margin 75
    
            has hbox
    
            # Les boutons en haut permettent à l'utilisateur
            # de sélectionner une page de fichiers.
            textbutton _("Auto"):
                action FilePage("auto")
    
            textbutton u"{font=gui/open-iconic.ttf}\uE02E{/font}":
                background None
                action FilePagePrevious()
                
            for i in range(1, 9):
                textbutton str(i):
                    action FilePage(i)
    
            textbutton  u"{font=gui/open-iconic.ttf}\uE02F{/font}":
                background None
                action FilePageNext()
    
        frame:
            
            $ columns = 2
            $ rows = 2
    
            # Affiche une grille d'emplacements de sauvegarde
            grid columns rows:
                transpose True
                xfill True
                spacing 10
                style_group "signets"
    
                # Montre dix emplacements, numérotés de 1 à 10.
                for i in range(1, columns * rows + 1):
    
                    # Chaque emplacement est un bouton.
                    button:
                        action If(renpy.get_screen("use_signet"),FileLoad(i),FileSave(i))
                        ypadding 10
                        xfill True
                        selected_hover_background Solid(couleur_ombre)
                        at action_souris
    
                        has hbox
                        xalign 0.0
    
                        # Ajoute un screenshot.
                        add FileScreenshot(i,empty = Fixed(Text(_("Empty"),xalign=0.5, yalign=0.5, style="signets_button_text"), Frame(recolorer("gui/cadre_bouton.png",couleur_insensitive),4,4),xsize = config.thumbnail_width , ysize = config.thumbnail_height) ) 
                        
                        null width 15
    
                        $ file_name = FileSlotName(i, columns * rows)
                        $ file_time = FileTime(i, empty="")
                        $ save_name = FileSaveName(i,empty="")
                        $ signet = _("Signet ")
    
                        text "{size=16}[signet!t][file_name]\n[file_time!t]{/size}{vspace=15}[save_name!t]"
    
                        key "save_delete" action FileDelete(i)


screen pose_signet:

    # Pour être sûr que tout autre menu est remplacé.
    tag menu

    use navigation(label_aide="aide_signets")
    
    text _(u"{font=gui/open-iconic.ttf}\uE021{/font} Set bookmark"):
        style "titre_ecran"

    
    use grille_signets

screen use_signet:

    # Pour être sûr que tout autre menu est remplacé.
    tag menu

    use navigation(label_aide="aide_signets")
    
    text _(u"{font=gui/open-iconic.ttf}\uE021{/font} Use bookmark"):
        style "titre_ecran"

    use grille_signets
    
init -2:
    style signets_vbox:
        spacing 10

    style signets_frame is cadre:
        xmargin 75
        ypadding 3
        xfill True

    style signets_hbox:
        xalign 0.5
        
    style signets_button is bouton_cadre:
        spacing 25
        xpadding 10
        ypadding 5
        xalign 0.5
        yminimum 45
        xminimum 45
        ymargin 5
        xmargin 5
        
    style signets_button_text is bouton_cadre_texte

    
    style signets_text is bouton_cadre_texte:
        text_align 0.0
        yalign 0.5
        
        
    # Ce transform permet de faire que les signets sont légèrement transparents et ne deviennent opaques qu'au passage de la souris.
    transform action_souris:
        on idle, selected_idle:
            alpha 0.75
        on hover, selected_hover:
            alpha 1.0
        on insensitive:
            alpha 0.5

##############################################################################
# Menu Oui/Non
#
# Écran proposant à l'utilisateur une question oui ou non
# http://www.renpy.org/doc/html/screen_special.html#yesno-prompt
#
# Simple restylage du code original

screen yesno_prompt:

    modal True

    window:
        style "ecran_options"

    frame:
        style_group "yesno"

        xfill True
        xmargin .05
        ypos .1
        yanchor 0
        ypadding .05

        has vbox:
            xalign .5
            yalign .5
            spacing 30

        label _(message):
            xalign 0.5

        hbox:
            xalign 0.5
            spacing 100

            textbutton _("Yes") action yes_action
            textbutton _("No") action no_action

    # Clic droit ou échap pour "non"
    key "game_menu" action no_action

init -2:
    
    style yesno:
        size_group "yesno"
    style yesno_label_text is libelle:
        text_align 0.5
        layout "subtitle"
        
    style yesno_button is bouton_cadre:
        ypadding 10
        xpadding 10
        
    style yesno_button_text is bouton_cadre_text
    
    style yesno_frame is cadre

